----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: reset_delay_gen - behavioral
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.2
-- Description: Reset Delay Generator
--
-- Last update: 2020-10-12
--
---------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_misc.all;

library UNISIM;
use UNISIM.VCOMPONENTS.all;

entity reset_delay_gen is

    generic (
        C_TICKS : integer := 10);

    port (
        ClkxCI          : in  std_ulogic;
        PllLockedxSI    : in  std_ulogic;
        ResetxRI        : in  std_ulogic;
        ResetDelayedxRO : out std_ulogic);

end entity reset_delay_gen;

architecture behavioral of reset_delay_gen is

    -- Signals
    signal ResetDelayxRD : std_ulogic_vector((C_TICKS - 1) downto 0) := (others => '1');

begin  -- architecture behavioral

    -- Asynchronous statements

    ResetDelayedxAS : ResetDelayedxRO <= ResetDelayxRD(C_TICKS - 1);

    -- Synchronous statements

    ResetDelayGenxP : process (ClkxCI) is
    begin  -- process ResetDelayGenxP
        if rising_edge(ClkxCI) then
            if PllLockedxSI = '0' then
                ResetDelayxRD <= (others => '1');
            elsif PllLockedxSI = '1' then
                ResetDelayxRD <= ResetDelayxRD((C_TICKS - 2) downto 0) & ResetxRI;
            end if;
        end if;
    end process ResetDelayGenxP;

end architecture behavioral;
